      PROGRAM main2
      IMPLICIT NONE

C
C   Christian Lanconelli
C   christian.lanconelli@ext.ec.europa.eu
C   Ver 2.1 - 2022-02-09 (RAMI4ATM Version)
C
C  The purpose of this program is to demonstrate the use of the RPV
C  function and to generate a test data set for verification
C  purposes. See rpv-in.dat for the input parameter definitions.
C
C  Compile as:
C  gfortran -std=legacy -finit-local-zero -o rpv2 main2_1.f rpv2_1.f
C
C  Define all variables and identifiers:
C
      INTEGER iunit
      REAL szini, szfin, szinc
      REAL vzini, vzfin, vzinc
      REAL raini, rafin, rainc
      INTEGER iszen, ivzen, irazi
      REAL istepn, vstepn, rstepn
      INTEGER err
      REAL rho0, k, bigtet, rhoc, refl
      REAL thetas, thetav, relphi
      REAL dg2rd
      REAL rpv2
      LOGICAL verbos
      EXTERNAL rpv2
      INTRINSIC REAL
      DATA dg2rd /1.745329E-2/
C
C  Open the scenario input file, read the values of the
C  variables for which computations need to be made, and close
C  the file:
C
      iunit = 10
      OPEN (UNIT = iunit, FILE = 'rpv-in.dat', STATUS = 'old')
      READ (iunit, *) rho0
      READ (iunit, *) k
      READ (iunit, *) bigtet
      READ (iunit, *) rhoc
      READ (iunit, *) szini
      READ (iunit, *) szfin
      READ (iunit, *) szinc
      READ (iunit, *) vzini
      READ (iunit, *) vzfin
      READ (iunit, *) vzinc
      READ (iunit, *) raini
      READ (iunit, *) rafin
      READ (iunit, *) rainc
      CLOSE (UNIT = iunit)
                  
C
C  Verify the correctness of input data:
C
      IF ((rho0 .LT. 0.0) .OR. (rho0 .GT. 2.0)) THEN
         WRITE (6, *) ' Invalid value of rho0.'
         GOTO 999
      ENDIF
      IF ((k .LT. 0.0) .OR. (k .GT. 2.0)) THEN
         WRITE (6, *) ' Invalid value of k.'
         GOTO 999
      ENDIF
      IF ((bigtet .LT. -1.0) .OR. (bigtet .GT. 1.0)) THEN
         WRITE (6, *) ' Invalid value of bigtet.'
         GOTO 999
      ENDIF
      IF ((rhoc .LT. 0.0) .OR. (rhoc .GT. 2.0)) THEN
         WRITE (6, *) ' Invalid value of rhoc.'
         GOTO 999
      ENDIF
      IF ((szini .LT. 0.0) .OR. (szini .GT. szfin) .OR. 
     &    (szfin .GT. 90.0)) THEN
         WRITE (6, *) ' Invalid value of szini or szfin.'
         GOTO 999
      ENDIF
      IF (szinc .LT. 0.0) THEN
         WRITE (6, *) ' Invalid value of szinc.'
         GOTO 999
      ENDIF
      IF ((vzini .LT. 0.0) .OR. (vzini .GT. vzfin) .OR. 
     &    (vzfin .GT. 90.0)) THEN
         WRITE (6, *) ' Invalid value of vzini or vzfin.'
         GOTO 999
      ENDIF
      IF (vzinc .LT. 0.0) THEN
         WRITE (6, *) ' Invalid value of vzinc.'
         GOTO 999
      ENDIF
      IF ((raini .LT. 0.0) .OR. (raini .GT. rafin)) THEN ! .OR. 
C   &    (rafin .GT. 180.0)) THEN
         WRITE (6, *) ' Invalid value of raini or rafin.'
         GOTO 999
      ENDIF
      IF (rainc .LT. 0.0) THEN
         WRITE (6, *) ' Invalid value of rainc.'
         GOTO 999
      ENDIF
C
C  Convert the solar zenith angles as required by RPV:
C

C C.Lanconelli (it is a fake requirement, see ABS(COS(sz)))
C Then I comment all lines in this version 2.0
C      szini = 180.0 - szini
C      szfin = 180.0 - szfin
C      szinc = -szinc

C
C  Loop over the angular conditions, convert angles from
C  degrees to radians, and set the verbose mode off:
C
      verbos = .FALSE.
C      verbos = .TRUE.

      istepn = (szfin - szini) / szinc
      vstepn = (vzfin - vzini) / vzinc
      rstepn = (rafin - raini) / rainc

C     WRITE (6, '(4A12)') 'Ill.zenith','Obs. zenith','Rel. azim.','RPV'
C  C.Lanconelli: Header changed to reflect the number of lcolumns of the output
      WRITE (6, '(4A12)') 'SZA', 'OZA', 'dPHI', 'RPV'
 
      WRITE (6, *)
      DO 100 iszen = 0, istepn, 1
         DO 200 ivzen = 0, vstepn , 1
            DO 300 irazi = 0, rstepn, 1
               thetas = (szini + REAL (iszen) *szinc) * dg2rd
               thetav = (vzini + REAL (ivzen) *vzinc) * dg2rd
               relphi = (raini + REAL (irazi) *rainc) * dg2rd
C
C  Compute the reflectance:
C
               refl = rpv2(thetas, thetav, relphi, rho0, k,
     &         bigtet, rhoc, verbos, err)
               WRITE (6, '(F12.1,F12.1,F12.1,F12.6)') REAL 
     &         (thetas / dg2rd), REAL (thetav / dg2rd), REAL 
     &	       (relphi / dg2rd), refl
  300       CONTINUE
  200    CONTINUE
  100 CONTINUE
C
  999 CONTINUE
      STOP
      END
